==> customer-space-portlet-1.2.2-sources.jar: org/exoplatform/cs/portlet/space/package-info.java <==
@Portlet
@Application(name = "SpaceController")
@Bindings({ @Binding(value = TicketService.class), @Binding(value = CSSpaceService.class), @Binding(value = TicketStatusFlowService.class),
    @Binding(value = OrganizationService.class) })
@Scripts({
    @Script(id = "jQueryUI", value = "js/lib/jquery-ui.js"),
    // AngularJS is still global, should be AMDified
    @Script(id = "angularjs", value = "js/lib/angular.min.js"),
    @Script(id = "ngSanitize", value = "js/lib/angular-sanitize.js", depends = "angularjs"),
    // services and controllers js are AMD modules, required by controllers.js
    @Script(id = "controllers", value = "js/controllers.js", depends = { "angularjs" }),
    @Script(id = "spaceAddon", value = "js/cs-space.js", depends = { "controllers" }) })
@Less("style/cs-space.less")
@Stylesheets({ @Stylesheet(id = "jQueryUISkin", value = "style/lib/jquery-ui.css"),
    @Stylesheet(id = "CSSpaceSkin", value = "style/cs-space-parent.css") })
@Assets("*")
package org.exoplatform.cs.portlet.space;

import juzu.Application;
import juzu.plugin.asset.Assets;
import juzu.plugin.asset.Script;
import juzu.plugin.asset.Scripts;
import juzu.plugin.asset.Stylesheet;
import juzu.plugin.asset.Stylesheets;
import juzu.plugin.binding.Binding;
import juzu.plugin.binding.Bindings;
import juzu.plugin.less.Less;
import juzu.plugin.portlet.Portlet;

import org.exoplatform.cs.service.CSSpaceService;
import org.exoplatform.cs.service.TicketService;
import org.exoplatform.cs.service.tickets.TicketStatusFlowService;
import org.exoplatform.services.organization.OrganizationService;

==> customer-space-portlet-1.3.1-sources.jar: org/exoplatform/cs/portlet/space/package-info.java <==
@Portlet
@Application(name = "SpaceController")
@Bindings({ @Binding(value = TicketService.class),
            @Binding(value = CSSpaceService.class),
            @Binding(value = TicketStatusFlowService.class),
            @Binding(value = SlaService.class),
            @Binding(value = SubscriptionService.class),
            @Binding(value = OrganizationService.class) })
@Scripts({
    @Script(id = "jQueryUI", value = "js/lib/jquery-ui.js"),
    // AngularJS is still global, should be AMDified
    @Script(id = "angularjs", value = "js/lib/angular.min.js"),
    @Script(id = "ngSanitize", value = "js/lib/angular-sanitize.js", depends = "angularjs"),
    // services and controllers js are AMD modules, required by controllers.js
    @Script(id = "controllers", value = "js/controllers.js", depends = { "angularjs" }),
    @Script(id = "spaceAddon", value = "js/cs-space.js", depends = { "controllers" }) })
@Less("style/cs-space.less")
@Stylesheets({ @Stylesheet(id = "jQueryUISkin", value = "style/lib/jquery-ui.css"),
    @Stylesheet(id = "CSSpaceSkin", value = "style/cs-space-parent.css") })
@Assets("*")
package org.exoplatform.cs.portlet.space;

import juzu.Application;
import juzu.plugin.asset.Assets;
import juzu.plugin.asset.Script;
import juzu.plugin.asset.Scripts;
import juzu.plugin.asset.Stylesheet;
import juzu.plugin.asset.Stylesheets;
import juzu.plugin.binding.Binding;
import juzu.plugin.binding.Bindings;
import juzu.plugin.less.Less;
import juzu.plugin.portlet.Portlet;

import org.exoplatform.cs.service.CSSpaceService;
import org.exoplatform.cs.service.TicketService;
import org.exoplatform.cs.service.sla.SlaService;
import org.exoplatform.cs.service.subscription.SubscriptionService;
import org.exoplatform.cs.service.tickets.TicketStatusFlowService;
import org.exoplatform.services.organization.OrganizationService;
